@@ -2,4 +2,4 @@ from django.apps import AppConfig
 
 
 class ModalConfig(AppConfig):
-    name = 'modal'
+    name = 'django_modals'
